===========
Change logs
===========

v0.1.1
======

:date: 2023-05-10 (JST)

Miscellaneous
-------------

* Update project metadata.

v0.1.0
======

:date: 2023-05-10 (JST)

Initial commit.

Features
--------

* Define ``og-article`` directive.

  * Support ``published_time`` and ``modified_time``.
  * Auto complement if missing ``_time`` properties.

* Define ``og_article_timezone`` config.
